# Cylestio Monitor Documentation

This directory contains the technical documentation for the Cylestio Monitor SDK. The documentation is organized into the following sections:

## Documentation Structure

- **Getting Started**: Basic setup and configuration
  - [Quick Start](getting-started/quick-start.md)
  - [Installation](getting-started/installation.md)
  - [Configuration](getting-started/configuration.md)

- **SDK Reference**: Detailed API documentation
  - [Overview](sdk-reference/overview.md)
  - [Monitor Module](sdk-reference/monitor.md)
  - [Events](sdk-reference/events.md)
  - [API Client](sdk-reference/api-client.md)

- **Security**: Security features and best practices
  - [Best Practices](security/best-practices.md)

- **Advanced Topics**: Advanced usage and customization
  - [Custom Integrations](advanced-topics/custom-integrations.md)
  - [Performance](advanced-topics/performance.md)
  - [Monitoring Channels](monitoring_channels.md)

- **Development**: Contributing to the project
  - [Contributing](development/contributing.md)
  - [Changelog](development/changelog.md)

- **Troubleshooting**: Common issues and solutions
  - [Common Issues](troubleshooting/common-issues.md)
  - [FAQs](troubleshooting/faqs.md)

## Integration with Centralized Documentation

This documentation is designed to be easily consumed by a centralized documentation repository. Each markdown file contains standalone content that can be pulled into a larger documentation system.

### Metadata Format

Each documentation file includes metadata in the frontmatter that can be used by the centralized documentation system:

```yaml
---
title: Document Title
description: Brief description of the document
category: getting-started|sdk-reference|security|advanced-topics|development|troubleshooting
order: 1
---
```

### Documentation Guidelines

- Each document focuses on a specific topic related to the Cylestio Monitor SDK
- Code examples are provided for common use cases
- Security best practices are emphasized throughout
- Cross-references use relative paths that can be adjusted in the centralized docs

## Standalone Usage

While this documentation is designed to be integrated with a centralized system, it can also be used as standalone documentation for the Cylestio Monitor SDK.

## Available Documentation

- [Getting Started](getting-started/)
- SDK Reference
  - [Events](sdk-reference/events.md)
  - [Monitor](sdk-reference/monitor.md)
  - [Tracing](sdk-reference/tracing.md)
  - [API Client](sdk-reference/api-client.md)
- Developer Guidelines
  - [Timestamps](developers/timestamps.md)
  - [Events](developers/events.md)
- [Troubleshooting](troubleshooting.md)
- [Custom Integrations](custom-integrations.md)
